import { Guid } from "guid-typescript";
import { Notifiable } from "../notifications/notifiable";
import { BooleanValidationContract } from "./boolean-validation-contract";
import { IValidatable } from "./contracts/ivalidatable";
import { GuidValidationContract } from "./guid-validator-contract";
import { NumberValidationContract } from "./number-validation-contract";
import { ObjectValidationContract } from "./object-validation-contract";
import { StringValidationContract } from "./string-validation-contract";
export declare class ValidationContract extends Notifiable implements StringValidationContract, NumberValidationContract, GuidValidationContract, ObjectValidationContract, BooleanValidationContract, IValidatable {
    /**
     * String Validation Contract
     */
    hasMinLen: (val: string, min: number, property: string, message: string) => ValidationContract;
    hasMaxLen: (val: string, max: number, property: string, message: string) => ValidationContract;
    hasLen: (val: string, len: number, property: string, message: string) => ValidationContract;
    isEmail: (email: string, property: string, message: string) => ValidationContract;
    isUrl: (url: string, property: string, message: string) => ValidationContract;
    match: (value: string, regex: RegExp, property: string, message: string) => ValidationContract;
    stringIsNotNullOrEmpty: (val: string, property: string, message: string) => ValidationContract;
    stringIsNullOrEmpty: (val: string, property: string, message: string) => ValidationContract;
    stringContains: (val: string, text: string, property: string, message: string) => ValidationContract;
    stringAreEquals: (val: string, text: string, property: string, message: string) => ValidationContract;
    stringAreNotEquals: (val: string, text: string, property: string, message: string) => ValidationContract;
    /**
     * Number Validation Contract
     */
    isGreaterThan: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    isGreaterOrEqualsThan: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    isLowerThan: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    isLowerOrEqualsThan: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    numberAreEquals: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    numberAreNotEquals: (val: number, comparer: number, property: string, message: string) => ValidationContract;
    isBetween: (val: number, from: number, to: number, property: string, message: string) => ValidationContract;
    /**
     * Guid Validation Contract
     */
    guidIsNotNullOrEmpty: (val: Guid, property: string, message: string) => ValidationContract;
    guidIsNullOrEmpty: (val: Guid, property: string, message: string) => ValidationContract;
    guidIsNotEmpty: (val: Guid, property: string, message: string) => ValidationContract;
    guidIsEmpty: (val: Guid, property: string, message: string) => ValidationContract;
    guidAreEquals: (val: Guid, comparer: Guid, property: string, message: string) => ValidationContract;
    guidAreNotEquals: (val: Guid, comparer: Guid, property: string, message: string) => ValidationContract;
    /**
     * Object Validation Contract
     */
    objectIsNotNull: (val: any, property: string, message: string) => ValidationContract;
    objectIsNull: (val: any, property: string, message: string) => ValidationContract;
    objectAreEquals: (val: any, compare: any, property: string, message: string) => ValidationContract;
    objectAreNotEquals: (val: any, compare: any, property: string, message: string) => ValidationContract;
    /**
     * Boolean Validation Contract
     */
    isTrue: (val: boolean, property: string, message: string) => ValidationContract;
    isFalse: (val: boolean, property: string, message: string) => ValidationContract;
    constructor();
    requires: () => ValidationContract;
    concat(notifiable: Notifiable): ValidationContract;
}
